API docs for “spamfighter.core.firewall.SkipToProcess”

# Class s.c.f.SkipToProcess(Exception):

Part of spamfighter.core.firewall View Source View In Hierarchy

Служебное исключение, используется для "пропуска" правил в файрволе.

Instance Variables | label | лейбл, до которого мы должны пропускать правила (type: `int` )
| pack | информация о обрабатываемом сообщении (type: `FirewallMessagePack` )

Method | __init__ | Конструктор.
Method | __repr__ | Undocumented
Method | __str | Undocumented

def __init__(self, label, pack): (source)
Конструктор.

def __repr__(self): (source)
Undocumented
def __str(self): (source)
Undocumented